@@ -57,14 +57,13 @@ populate_tree_branch (CappletDir *dir, GtkCTree *ctree, GtkCTreeNode *parent)
 	for (list = dir->entries; list; list = list->next) {
 		entry = CAPPLET_DIR_ENTRY (list->data);
 
-		pixbuf = gdk_pixbuf_new_from_file (entry->icon);
+		pixbuf = gdk_pixbuf_new_from_file (entry->icon, NULL);
 		scaled = gdk_pixbuf_scale_simple (pixbuf, 16, 16, 
 						  GDK_INTERP_BILINEAR);
 		gdk_pixbuf_render_pixmap_and_mask (scaled, &pixmap, &mask, 128);
 		gdk_pixbuf_unref (pixbuf);
 		gdk_pixbuf_unref (scaled);
 
-#warning Should an array be created instead of passing &entry->label ?
 		current = gtk_ctree_insert_node 
 			(ctree, parent, NULL,
 			 &entry->label, 10,
@@ -121,7 +120,6 @@ tree_event_cb (GtkCTree *ctree, GdkEventButton *event,
 static GtkWidget *
 tree_create (CappletDirView *view) 
 {
-	GtkAdjustment *adjustment;
 	GtkWidget *w, *sw;
 	
 	sw = gtk_scrolled_window_new (NULL, NULL);
