@@ -1,6 +1,6 @@
 #include "sound-properties.h"
 #include <config.h>
-#include <gtk/gtksignal.h>
+#include <gtk/gtk.h>
 #include <string.h>
 #include <stdlib.h>
 /* opendir */
@@ -86,31 +86,28 @@ sound_properties_class_init (GtkObjectClass *object_class)
 	sound_properties_parent_class = gtk_type_class (gtk_object_get_type ());
 
 	sound_properties_signals[EVENT_ADDED] =
-		gtk_signal_new ("event_added", GTK_RUN_LAST, object_class->type,
+		gtk_signal_new ("event_added", GTK_RUN_LAST, G_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (SoundPropertiesClass, event_added),
-				gtk_marshal_NONE__OBJECT, GTK_TYPE_NONE, 1,
+				gtk_marshal_NONE__POINTER, GTK_TYPE_NONE, 1,
 				GTK_TYPE_POINTER);
 
 	sound_properties_signals[EVENT_REMOVED] =
-		gtk_signal_new ("event_removed", GTK_RUN_LAST, object_class->type,
+		gtk_signal_new ("event_removed", GTK_RUN_LAST, G_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (SoundPropertiesClass, event_removed),
-				gtk_marshal_NONE__OBJECT, GTK_TYPE_NONE, 1,
+				gtk_marshal_NONE__POINTER, GTK_TYPE_NONE, 1,
 				GTK_TYPE_POINTER);
 
 	sound_properties_signals[EVENT_CHANGED] =
-		gtk_signal_new ("event_changed", GTK_RUN_LAST, object_class->type,
+		gtk_signal_new ("event_changed", GTK_RUN_LAST, G_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (SoundPropertiesClass, event_changed),
-				gtk_marshal_NONE__OBJECT, GTK_TYPE_NONE, 1,
+				gtk_marshal_NONE__POINTER, GTK_TYPE_NONE, 1,
 				GTK_TYPE_POINTER);
 
 	sound_properties_signals[CHANGED] =
-		gtk_signal_new ("changed", GTK_RUN_LAST, object_class->type,
+		gtk_signal_new ("changed", GTK_RUN_LAST, G_OBJECT_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (SoundPropertiesClass, changed),
 				gtk_marshal_NONE__NONE, GTK_TYPE_NONE, 0);
 
-	gtk_object_class_add_signals (object_class, sound_properties_signals,
-				      LAST_SIGNAL);
-
 	object_class->destroy = sound_properties_destroy;
 }
 
